summaryrefslogtreecommitdiffstats
path: root/src/location/declarativemaps/qdeclarativerectanglemapitem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/location/declarativemaps/qdeclarativerectanglemapitem.cpp')
-rw-r--r--src/location/declarativemaps/qdeclarativerectanglemapitem.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/location/declarativemaps/qdeclarativerectanglemapitem.cpp b/src/location/declarativemaps/qdeclarativerectanglemapitem.cpp
index 3028d4cc..cd825cc8 100644
--- a/src/location/declarativemaps/qdeclarativerectanglemapitem.cpp
+++ b/src/location/declarativemaps/qdeclarativerectanglemapitem.cpp
@@ -377,10 +377,10 @@ void QDeclarativeRectangleMapItem::setGeoShape(const QGeoShape &shape)
/*!
\internal
*/
-void QDeclarativeRectangleMapItem::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
+void QDeclarativeRectangleMapItem::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
{
if (!map() || !m_rectangle.isValid() || m_updatingGeometry || newGeometry.topLeft() == oldGeometry.topLeft()) {
- QDeclarativeGeoMapItemBase::geometryChanged(newGeometry, oldGeometry);
+ QDeclarativeGeoMapItemBase::geometryChange(newGeometry, oldGeometry);
return;
}
// TODO: change the algorithm to preserve the distances and size
@@ -398,7 +398,7 @@ void QDeclarativeRectangleMapItem::geometryChanged(const QRectF &newGeometry, co
emit topLeftChanged(m_rectangle.topLeft());
emit bottomRightChanged(m_rectangle.bottomRight());
// Not calling QDeclarativeGeoMapItemBase::geometryChanged() as it will be called from a nested
// call to this function.
}
@@ -398,7 +398,7 @@ void QDeclarativeRectangleMapItem::geometryChanged(const QRectF &newGeometry, co
emit topLeftChanged(m_rectangle.topLeft());
emit bottomRightChanged(m_rectangle.bottomRight());
- // Not calling QDeclarativeGeoMapItemBase::geometryChanged() as it will be called from a nested
+ // Not calling QDeclarativeGeoMapItemBase::geometryChange() as it will be called from a nested
// call to this function.
}